==> ng2-bootstrap-0.34.6.tgz: package/README.md <==
# angular2-bootstrap
Native Angular2 directives for Bootstrap

Goal: smooth transition from ui-bootstrap to angular2,
all components will have same API

[![Code Climate](https://codeclimate.com/github/valor-software/angular2-bootstrap/badges/gpa.svg)](https://codeclimate.com/github/valor-software/angular2-bootstrap)
[![devDependency Status](https://david-dm.org/valor-software/angular2-bootstrap/dev-status.svg)](https://david-dm.org/valor-software/angular2-bootstrap#info=devDependencies)
<!---
[![Test Coverage](https://codeclimate.com/github/valor-software/angular2-bootstrap/badges/coverage.svg)](https://codeclimate.com/github/valor-software/angular2-bootstrap/coverage)
-->

# Demo

[http://valor-software.github.io/angular2-bootstrap/](http://valor-software.github.io/angular2-bootstrap/)

# Components

- [x] Accordion
- [x] Alert ([ ] template url)
- [x] Buttons
- [ ] Carousel
- [x] Collapse ([ ] animate)
- [ ] Datepicker
- [x] Dropdown ([ ] template url, [ ] append to body)
- [ ] Modal
- [ ] Pagination
- [ ] Popover
- [x] Progressbar
- [ ] Rating  (in progress...)
- [ ] Tabs
- [ ] Timepicker
- [+-] Tooltip (baseline working, in progress...)
- [ ] Typeahead

- [x] positional service
- [ ] template url support

## Jump on board! :)

```bash
  npm i
  npm start
```

### TODO
- [ ] find a better way to detect is event handler is set (see alerts.ts)
- [ ] support `templateUrl` for directives
- [ ] demo page
- [ ] docs
- [ ] support animation
- [ ] publish to npm, bower, etc.
- [ ] migration guide from Angular 1 to Angular 2

==> ng2-bootstrap-0.34.8.tgz: package/README.md <==
# angular2-bootstrap
Native Angular2 directives for Bootstrap

Goal: smooth transition from ui-bootstrap to angular2,
all components will have same API

[![Code Climate](https://codeclimate.com/github/valor-software/angular2-bootstrap/badges/gpa.svg)](https://codeclimate.com/github/valor-software/angular2-bootstrap)
[![devDependency Status](https://david-dm.org/valor-software/angular2-bootstrap/dev-status.svg)](https://david-dm.org/valor-software/angular2-bootstrap#info=devDependencies)
<!---
[![Test Coverage](https://codeclimate.com/github/valor-software/angular2-bootstrap/badges/coverage.svg)](https://codeclimate.com/github/valor-software/angular2-bootstrap/coverage)
-->

# Demo

[http://valor-software.github.io/angular2-bootstrap/](http://valor-software.github.io/angular2-bootstrap/)

# Components

- [x] Accordion
- [x] Alert ([ ] template url)
- [x] Buttons
- [ ] Carousel
- [x] Collapse ([ ] animate)
- [ ] Datepicker
- [x] Dropdown ([ ] template url, [ ] append to body)
- [ ] Modal
- [ ] Pagination  (in progress...)
- [ ] Popover
- [x] Progressbar
- [x] Rating
- [ ] Tabs
- [ ] Timepicker
- [+-] Tooltip (baseline working, in progress...)
- [ ] Typeahead

- [x] positional service
- [ ] template url support

## Jump on board! :)

```bash
  npm i
  npm start
```

### TODO
- [ ] find a better way to detect is event handler is set (see alerts.ts)
- [ ] support `templateUrl` for directives
- [ ] demo page
- [ ] docs
- [ ] support animation
- [ ] publish to npm, bower, etc.
- [ ] migration guide from Angular 1 to Angular 2
